require 'handiv/configuration'
require 'handiv/logger'

require 'handiv/tasks/reporter'

module Handiv
  class Client
    attr_reader :options

    def initialize(options = {})
      @options = options

      set_config_from_options
    end

    def logger
      @logger ||= Logger.new(self)
    end

    def configuration
      @configuration ||= Configuration.new
    end
    alias config configuration

    def connection
      Connection.new(self)
    end

    def configure
      yield(configuration) if block_given?
      true
    end

    def report_task(task_id, options = {})
      Tasks::Reporter.new(self, task_id, options).report
    end

    private

    def set_config_from_options
      options.each do |key, value|
        next unless configuration.respond_to?("#{key}=")

        configuration.send("#{key}=", value)
      end
    end
  end
end
