module Handiv
  class Configuration
    class Error < StandardError; end

    DEFAULT_HOST = 'ping.handiv.com'.freeze

    # Host that will be used for connections
    attr_accessor :host

    attr_accessor :ssl

    # General authentication data
    attr_accessor :organization_id
    attr_accessor :app_id
    attr_accessor :secret_token

    # Timeout when waiting for the server to return data in seconds
    attr_accessor :timeout

    # Timeout waiting for the connection to open in seconds
    attr_accessor :open_timeout

    # Proxy information to pass to the HTTP adapter
    attr_accessor :proxy

    # Logger to use internally
    attr_accessor :logger

    def initialize
      set_default_configs
      set_faraday_configs
    end

    def ssl?
      ssl
    end

    def uri
      scheme = ssl? ? 'https' : 'http'
      "#{scheme}://#{host}"
    end

    def verify!
      raise Error, 'No organization id specified.' unless organization_id
      raise Error, 'No app id specified.' unless app_id
      raise Error, 'No secret token specified.' unless secret_token
    end

    private

    def set_default_configs
      @ssl = true
      @host = DEFAULT_HOST
    end

    def set_faraday_configs
      @timeout = 3
      @open_timeout = 3
    end
  end
end
