require 'faraday'
require 'faraday_middleware'
require 'json'

module Handiv
  class Connection
    USER_AGENT = "handiv-ruby/#{Handiv::VERSION}".freeze

    attr_reader :client, :connection

    def initialize(client)
      @client = client
      @connection = set_connection
    end

    def send_data(path, data = {})
      config.verify!

      response = post_data(path, data)
      response.status
    rescue => e
      client.logger.error "Failed to send a message (#{e.class} - #{e.message})"
      500 # Return status
    end

    private

    def post_data(path, data)
      connection.post do |req|
        req.url(path)
        req.headers['Content-Type'] = 'application/json'
        req.headers['Authorization'] = "Token token=#{config.secret_token}"
        req.body = data.to_json
      end
    end

    def ping_url
      "#{config.uri}/#{config.organization_id}/#{config.app_id}"
    end

    def set_connection
      Faraday.new(url: ping_url) do |conn|
        config_general_options(conn)
        conn.response :follow_redirects
        conn.request :url_encoded # for POST/PUT params
        conn.request :retry

        conn.adapter Faraday.default_adapter
      end
    end

    def config_general_options(conn)
      conn.headers[:user_agent] = USER_AGENT
      conn.options[:proxy] = config.proxy if config.proxy
      conn.options[:timeout] = config.timeout if config.timeout
      conn.options[:open_timeout] = config.open_timeout if config.open_timeout
    end

    def config
      client.config
    end
  end
end
