require 'logger'

module Handiv
  class Logger
    attr_reader :client

    LOG_PREFIX = '** [Handiv] '.freeze
    LOG_LEVELS = [:fatal, :error, :warn, :info, :debug].freeze

    LOG_LEVELS.each do |level|
      define_method(level) do |*args, &block|
        msg = args[0] # Block-level default args is a 1.9 feature
        msg ||= block.call if block

        logger.send(level, "#{LOG_PREFIX}#{msg}")
      end
    end

    def initialize(client)
      @client = client
    end

    def logger
      custom_logger || default_logger
    end

    private

    def default_logger
      @default_logger ||= ::Logger.new(STDOUT)
    end

    def custom_logger
      client.configuration.logger
    end
  end
end
